;; Generated package description from code-cells.el  -*- no-byte-compile: t -*-
(define-package "code-cells" "0.3" "Lightweight notebooks with support for ipynb files" '((emacs "27.1")) :commit "fd68a33eb43b3cbd44fed767f48e230382903592" :authors '(("Augusto Stoffel" . "arstoffel@gmail.com")) :maintainer '("Augusto Stoffel" . "arstoffel@gmail.com") :keywords '("convenience" "outlines") :url "https://github.com/astoff/code-cells.el")
